@@ -1,8 +1,8 @@
-### rtree.R (2005-06-14)
+### rtree.R (2006-07-07)
 ###
 ###          Generates Random Trees
 ###
-### Copyright 2004-2005 Emmanuel Paradis
+### Copyright 2004-2006 Emmanuel Paradis
 ###
 ### This file is part of the `ape' library for R and related languages.
 ### It is made available under the terms of the GNU General Public
@@ -22,54 +22,95 @@
 
 rtree <- function(n, rooted = TRUE, tip.label = NULL, br = runif, ...)
 {
+    foo <- function(n, pos) {
+        n1 <- .Internal(sample(n - 1, 1, FALSE, NULL))
+        n2 <- n - n1
+        po2 <- pos + 2*n1 - 1
+        edge[c(pos, po2), 1] <<- nod
+        nod <<- nod - 1
+        if (n1 > 2) {
+            edge[pos, 2] <<- nod
+            foo(n1, pos + 1)
+        } else if (n1 == 2) {
+            edge[c(pos + 1, pos + 2), 1] <<- edge[pos, 2] <<- nod
+            nod <<- nod - 1
+        }
+        if (n2 > 2) {
+            edge[po2, 2] <<- nod
+            foo(n2, po2 + 1)
+        } else if (n2 == 2) {
+            edge[c(po2 + 1, po2 + 2), 1] <<- edge[po2, 2] <<- nod
+            nod <<- nod - 1
+        }
+    }
+
+    if (n < 2) stop("a tree must have at least 2 tips.")
     nbr <- 2 * n - 2
     if (!rooted) nbr <- nbr - 1
     edge <- matrix(NA, nbr, 2)
+
     if (n == 2) {
-        if (rooted) {
-            edge[, 1] <- -1
-            edge[, 2] <- 1:2
-        } else edge[1, ] <- 1:2
+        if (rooted) edge[] <- c(-1, -1, 1, 2)
+        else stop("an unrooted tree must have at least 3 tips.")
     } else if (n == 3) {
-        if (rooted) {
-            edge[, 1] <- c(-1, -2, -2, -1)
-            edge[, 2] <- c(-2, 1:3)
-        } else {
-            edge[, 1] <- -1
-            edge[, 2] <- 1:3
-        }
+        edge[] <-
+          if (rooted) c(-1, -2, -2, -1, -2, 1:3)
+          else c(-1, -1, -1, 1:3)
     } else if (n == 4 && !rooted) {
-        edge[, 1] <- c(-1, -2, -2, -1, -1)
-        edge[, 2] <- c(-2, 1:4)
+        edge[] <- c(-1, -2, -2, -1, -1, -2, 1:4)
     } else {
-        if (rooted) {
-            edge[1:2, 1] <- 1
-            rnd <- ceiling(runif(n - 2, 0, 2:(n - 1)))
-            for (i in 2:(n - 1)) {
-                edge[which(is.na(edge[1:((i - 1) * 2), 2]))[rnd[i - 1]], 2] <- i
-                edge[(i - 1) * 2 + 1, 1] <- i
-                edge[(i - 1) * 2 + 2, 1] <- i
+        nod <- -1
+        if (rooted) { # n > 3
+            foo(n, 1)
+            ## The following is slightly more efficient than affecting the
+            ## tip numbers in foo(): the gain is 0.006 s for n = 1000!
+            i <- which(is.na(edge[, 2]))
+            edge[i, 2] <- 1:n
+        } else { # n > 4
+            n1 <- .Internal(sample(n - 2, 1, FALSE, NULL))
+            if (n1 == n - 2) {
+                n2 <- n3 <- 1
+            } else {
+                n2 <- .Internal(sample(n - n1 - 1, 1, FALSE, NULL))
+                n3 <- n - n1 - n2
             }
-        } else {
-            edge[1:3, 1] <- 1                          # != the rooted case
-            rnd <- ceiling(runif(n - 3, 0, 2:(n - 3))) # != the rooted case
-            for (i in 2:(n - 2)) {
-                edge[which(is.na(edge[1:((i - 1) * 2), 2]))[rnd[i - 1]], 2] <- i
-                edge[(i - 1) * 2 + 2, 1] <- i # these two lines differ
-                edge[(i - 1) * 2 + 3, 1] <- i # from the rooted case
+            po2 <- 2*n1
+            po3 <- 2*(n1 + n2) - 1
+            edge[c(1, po2, po3), 1] <- nod
+            nod <- nod - 1
+            if (n1 > 2) {
+                edge[1, 2] <- nod
+                foo(n1, 2)
+            } else if (n1 == 2) {
+                edge[2:3, 1] <- edge[1, 2] <- nod
+                nod <- nod - 1
             }
+            if (n2 > 2) {
+                edge[po2, 2] <- nod
+                foo(n2, po2 + 1)
+            } else if (n2 == 2) {
+                edge[c(po2 + 1, po2 + 2), 1] <- edge[po2, 2] <- nod
+                nod <- nod - 1
+            }
+            if (n3 > 2) {
+                edge[po3, 2] <- nod
+                foo(n3, po3 + 1)
+            } else if (n3 == 2) {
+                edge[c(po3 + 1, po3 + 2), 1] <- edge[po3, 2] <- nod
+                ## nod <- nod - 1
+            }
+            i <- which(is.na(edge[, 2]))
+            edge[i, 2] <- 1:n
         }
-        edge <- -edge
-        edge[, 2][is.na(edge[, 2])] <- 1:n
     }
     mode(edge) <- "character"
     phy <- list(edge = edge)
     phy$tip.label <-
       if (is.null(tip.label)) paste("t", 1:n, sep = "")
       else sample(tip.label)
-    class(phy) <- "phylo"
     if (is.function(br)) phy$edge.length <- br(nbr, ...)
-    read.tree(text = write.tree(phy, multi.line = FALSE))
+    class(phy) <- "phylo"
+    phy
 }
 
 rcoal <- function(n, tip.label = NULL, br = rexp, ...)
