@@ -77,7 +77,7 @@ yule.cov <- function(phy, formula, data = NULL)
     else para[, 2] <- sqrt(diag(solve(out$hessian)))
     rownames(para) <- colnames(X)
     colnames(para) <- c("Estimate", "StdErr")
-    cat("\n---- Yule Model With Covariates ----\n\n")
+    cat("\n---- Yule Model with Covariates ----\n\n")
     cat("    Phylogenetic tree:", deparse(substitute(phy)), "\n")
     cat("       Number of tips:", nb.tip, "\n")
     cat("      Number of nodes:", nb.node, "\n")
